# coding: utf-8

"""
    Selling Partner API for Sellers

    The Selling Partner API for Sellers lets you retrieve information on behalf of sellers about their seller account, such as the marketplaces they participate in. Along with listing the marketplaces that a seller can sell in, the API also provides additional information about the marketplace such as the default language and the default currency. The API also provides seller-specific information such as whether the seller has suspended listings in that marketplace.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from models.marketplace_participation_list import MarketplaceParticipationList  # noqa: E501
from swagger_client.rest import ApiException


class TestMarketplaceParticipationList(unittest.TestCase):
    """MarketplaceParticipationList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testMarketplaceParticipationList(self):
        """Test MarketplaceParticipationList"""
        # FIXME: construct object with mandatory attributes with example values
        # model = swagger_client.models.marketplace_participation_list.MarketplaceParticipationList()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
