# coding: utf-8

"""
    Selling Partner API for Notifications

    The Selling Partner API for Notifications lets you subscribe to notifications that are relevant to a selling partner's business. Using this API you can create a destination to receive notifications, subscribe to notifications, delete notification subscriptions, and more.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from models.create_subscription_request import CreateSubscriptionRequest  # noqa: E501
from swagger_client.rest import ApiException


class TestCreateSubscriptionRequest(unittest.TestCase):
    """CreateSubscriptionRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCreateSubscriptionRequest(self):
        """Test CreateSubscriptionRequest"""
        # FIXME: construct object with mandatory attributes with example values
        # model = swagger_client.models.create_subscription_request.CreateSubscriptionRequest()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
