# coding: utf-8

"""
    Selling Partner API for Finances

    The Selling Partner API for Finances helps you obtain financial information relevant to a seller's business. You can obtain financial events for a given order, financial event group, or date range without having to wait until a statement period closes. You can also obtain financial event groups for a given date range.  # noqa: E501

    OpenAPI spec version: v0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class DebtRecoveryItem(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'recovery_amount': 'Currency',
        'original_amount': 'Currency',
        'group_begin_date': 'ModelDate',
        'group_end_date': 'ModelDate'
    }

    attribute_map = {
        'recovery_amount': 'RecoveryAmount',
        'original_amount': 'OriginalAmount',
        'group_begin_date': 'GroupBeginDate',
        'group_end_date': 'GroupEndDate'
    }

    def __init__(self, recovery_amount=None, original_amount=None, group_begin_date=None, group_end_date=None):  # noqa: E501
        """DebtRecoveryItem - a model defined in Swagger"""  # noqa: E501
        self._recovery_amount = None
        self._original_amount = None
        self._group_begin_date = None
        self._group_end_date = None
        self.discriminator = None
        if recovery_amount is not None:
            self.recovery_amount = recovery_amount
        if original_amount is not None:
            self.original_amount = original_amount
        if group_begin_date is not None:
            self.group_begin_date = group_begin_date
        if group_end_date is not None:
            self.group_end_date = group_end_date

    @property
    def recovery_amount(self):
        """Gets the recovery_amount of this DebtRecoveryItem.  # noqa: E501


        :return: The recovery_amount of this DebtRecoveryItem.  # noqa: E501
        :rtype: Currency
        """
        return self._recovery_amount

    @recovery_amount.setter
    def recovery_amount(self, recovery_amount):
        """Sets the recovery_amount of this DebtRecoveryItem.


        :param recovery_amount: The recovery_amount of this DebtRecoveryItem.  # noqa: E501
        :type: Currency
        """

        self._recovery_amount = recovery_amount

    @property
    def original_amount(self):
        """Gets the original_amount of this DebtRecoveryItem.  # noqa: E501


        :return: The original_amount of this DebtRecoveryItem.  # noqa: E501
        :rtype: Currency
        """
        return self._original_amount

    @original_amount.setter
    def original_amount(self, original_amount):
        """Sets the original_amount of this DebtRecoveryItem.


        :param original_amount: The original_amount of this DebtRecoveryItem.  # noqa: E501
        :type: Currency
        """

        self._original_amount = original_amount

    @property
    def group_begin_date(self):
        """Gets the group_begin_date of this DebtRecoveryItem.  # noqa: E501


        :return: The group_begin_date of this DebtRecoveryItem.  # noqa: E501
        :rtype: ModelDate
        """
        return self._group_begin_date

    @group_begin_date.setter
    def group_begin_date(self, group_begin_date):
        """Sets the group_begin_date of this DebtRecoveryItem.


        :param group_begin_date: The group_begin_date of this DebtRecoveryItem.  # noqa: E501
        :type: ModelDate
        """

        self._group_begin_date = group_begin_date

    @property
    def group_end_date(self):
        """Gets the group_end_date of this DebtRecoveryItem.  # noqa: E501


        :return: The group_end_date of this DebtRecoveryItem.  # noqa: E501
        :rtype: ModelDate
        """
        return self._group_end_date

    @group_end_date.setter
    def group_end_date(self, group_end_date):
        """Sets the group_end_date of this DebtRecoveryItem.


        :param group_end_date: The group_end_date of this DebtRecoveryItem.  # noqa: E501
        :type: ModelDate
        """

        self._group_end_date = group_end_date

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DebtRecoveryItem, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DebtRecoveryItem):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
