# coding: utf-8

"""
    Selling Partner API for Orders

    The Selling Partner API for Orders helps you programmatically retrieve order information. These APIs let you develop fast, flexible, custom applications in areas like order synchronization, order research, and demand-based decision support tools.  # noqa: E501

    OpenAPI spec version: v0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from models.order_item_list import OrderItemList  # noqa: E501
from swagger_client.rest import ApiException


class TestOrderItemList(unittest.TestCase):
    """OrderItemList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testOrderItemList(self):
        """Test OrderItemList"""
        # FIXME: construct object with mandatory attributes with example values
        # model = swagger_client.models.order_item_list.OrderItemList()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
