# coding: utf-8

"""
    Selling Partner API for Orders

    The Selling Partner API for Orders helps you programmatically retrieve order information. These APIs let you develop fast, flexible, custom applications in areas like order synchronization, order research, and demand-based decision support tools.  # noqa: E501

    OpenAPI spec version: v0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from models.payment_method_detail_item_list import PaymentMethodDetailItemList  # noqa: E501
from swagger_client.rest import ApiException


class TestPaymentMethodDetailItemList(unittest.TestCase):
    """PaymentMethodDetailItemList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testPaymentMethodDetailItemList(self):
        """Test PaymentMethodDetailItemList"""
        # FIXME: construct object with mandatory attributes with example values
        # model = swagger_client.models.payment_method_detail_item_list.PaymentMethodDetailItemList()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
