# coding: utf-8

"""
    Selling Partner API for Reports

    The Selling Partner API for Reports lets you retrieve and manage a variety of reports that can help selling partners manage their businesses.  # noqa: E501

    OpenAPI spec version: 2020-09-04
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from models.report_schedule_list import ReportScheduleList  # noqa: E501
from swagger_client.rest import ApiException


class TestReportScheduleList(unittest.TestCase):
    """ReportScheduleList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testReportScheduleList(self):
        """Test ReportScheduleList"""
        # FIXME: construct object with mandatory attributes with example values
        # model = swagger_client.models.report_schedule_list.ReportScheduleList()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
