# coding: utf-8

"""
    Selling Partner API for Product Fees

    The Selling Partner API for Product Fees lets you programmatically retrieve estimated fees for a product. You can then account for those fees in your pricing.  # noqa: E501

    OpenAPI spec version: v0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from models.get_my_fees_estimate_request import GetMyFeesEstimateRequest  # noqa: E501
from swagger_client.rest import ApiException


class TestGetMyFeesEstimateRequest(unittest.TestCase):
    """GetMyFeesEstimateRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetMyFeesEstimateRequest(self):
        """Test GetMyFeesEstimateRequest"""
        # FIXME: construct object with mandatory attributes with example values
        # model = swagger_client.models.get_my_fees_estimate_request.GetMyFeesEstimateRequest()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
