# coding: utf-8

"""
    Selling Partner API for Product Fees

    The Selling Partner API for Product Fees lets you programmatically retrieve estimated fees for a product. You can then account for those fees in your pricing.  # noqa: E501

    OpenAPI spec version: v0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class FeesEstimateError(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'str',
        'code': 'str',
        'message': 'str',
        'detail': 'FeesEstimateErrorDetail'
    }

    attribute_map = {
        'type': 'Type',
        'code': 'Code',
        'message': 'Message',
        'detail': 'Detail'
    }

    def __init__(self, type=None, code=None, message=None, detail=None):  # noqa: E501
        """FeesEstimateError - a model defined in Swagger"""  # noqa: E501
        self._type = None
        self._code = None
        self._message = None
        self._detail = None
        self.discriminator = None
        self.type = type
        self.code = code
        self.message = message
        self.detail = detail

    @property
    def type(self):
        """Gets the type of this FeesEstimateError.  # noqa: E501

        An error type, identifying either the receiver or the sender as the originator of the error.  # noqa: E501

        :return: The type of this FeesEstimateError.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this FeesEstimateError.

        An error type, identifying either the receiver or the sender as the originator of the error.  # noqa: E501

        :param type: The type of this FeesEstimateError.  # noqa: E501
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def code(self):
        """Gets the code of this FeesEstimateError.  # noqa: E501

        An error code that identifies the type of error that occurred.  # noqa: E501

        :return: The code of this FeesEstimateError.  # noqa: E501
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this FeesEstimateError.

        An error code that identifies the type of error that occurred.  # noqa: E501

        :param code: The code of this FeesEstimateError.  # noqa: E501
        :type: str
        """
        if code is None:
            raise ValueError("Invalid value for `code`, must not be `None`")  # noqa: E501

        self._code = code

    @property
    def message(self):
        """Gets the message of this FeesEstimateError.  # noqa: E501

        A message that describes the error condition in a human-readable form.  # noqa: E501

        :return: The message of this FeesEstimateError.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this FeesEstimateError.

        A message that describes the error condition in a human-readable form.  # noqa: E501

        :param message: The message of this FeesEstimateError.  # noqa: E501
        :type: str
        """
        if message is None:
            raise ValueError("Invalid value for `message`, must not be `None`")  # noqa: E501

        self._message = message

    @property
    def detail(self):
        """Gets the detail of this FeesEstimateError.  # noqa: E501


        :return: The detail of this FeesEstimateError.  # noqa: E501
        :rtype: FeesEstimateErrorDetail
        """
        return self._detail

    @detail.setter
    def detail(self, detail):
        """Sets the detail of this FeesEstimateError.


        :param detail: The detail of this FeesEstimateError.  # noqa: E501
        :type: FeesEstimateErrorDetail
        """
        if detail is None:
            raise ValueError("Invalid value for `detail`, must not be `None`")  # noqa: E501

        self._detail = detail

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(FeesEstimateError, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FeesEstimateError):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
