# coding: utf-8

"""
    Selling Partner API for Finances

    The Selling Partner API for Finances helps you obtain financial information relevant to a seller's business. You can obtain financial events for a given order, financial event group, or date range without having to wait until a statement period closes. You can also obtain financial event groups for a given date range.  # noqa: E501

    OpenAPI spec version: v0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from models.shipment_event import ShipmentEvent  # noqa: E501
from swagger_client.rest import ApiException


class TestShipmentEvent(unittest.TestCase):
    """ShipmentEvent unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testShipmentEvent(self):
        """Test ShipmentEvent"""
        # FIXME: construct object with mandatory attributes with example values
        # model = swagger_client.models.shipment_event.ShipmentEvent()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
